aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2012-01-12 11:35:50 -0800
committerBen Pfaff <blp@nicira.com>2012-01-12 11:35:50 -0800
commit73dbf4abd17b6b87fdb5bf22aec7bb3d381dce05 (patch)
tree9f543b9f4dbcc021996922b89195f3d5966e2a80
parent2b3ed2a67da502875a3877f0b159781d0a458e8a (diff)
nicira-ext: Rename "struct nxt_*" to "struct nx_*".
Most structures in this file have an "nx_" prefix, so this makes naming more consistent. Signed-off-by: Ben Pfaff <blp@nicira.com>
-rw-r--r--include/openflow/nicira-ext.h20
-rw-r--r--lib/ofp-print.c8
-rw-r--r--lib/ofp-util.c20
-rw-r--r--ofproto/ofproto.c12
4 files changed, 30 insertions, 30 deletions
diff --git a/lib/ofp-print.c b/lib/ofp-print.c
index 67edc543..89267d87 100644
--- a/lib/ofp-print.c
+++ b/lib/ofp-print.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2008, 2009, 2010, 2011 Nicira Networks.
+ * Copyright (c) 2008, 2009, 2010, 2011, 2012 Nicira Networks.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -1253,14 +1253,14 @@ ofp_print_nxt_role_message(struct ds *string,
static void
ofp_print_nxt_flow_mod_table_id(struct ds *string,
- const struct nxt_flow_mod_table_id *nfmti)
+ const struct nx_flow_mod_table_id *nfmti)
{
ds_put_format(string, " %s", nfmti->set ? "enable" : "disable");
}
static void
ofp_print_nxt_set_flow_format(struct ds *string,
- const struct nxt_set_flow_format *nsff)
+ const struct nx_set_flow_format *nsff)
{
uint32_t format = ntohl(nsff->format);
@@ -1274,7 +1274,7 @@ ofp_print_nxt_set_flow_format(struct ds *string,
static void
ofp_print_nxt_set_packet_in_format(struct ds *string,
- const struct nxt_set_packet_in_format *nspf)
+ const struct nx_set_packet_in_format *nspf)
{
uint32_t format = ntohl(nspf->format);
diff --git a/lib/ofp-util.c b/lib/ofp-util.c
index 1c9ceaf8..850d757b 100644
--- a/lib/ofp-util.c
+++ b/lib/ofp-util.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2008, 2009, 2010, 2011 Nicira Networks.
+ * Copyright (c) 2008, 2009, 2010, 2011, 2012 Nicira Networks.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -361,15 +361,15 @@ ofputil_decode_vendor(const struct ofp_header *oh, size_t length,
{ OFPUTIL_NXT_SET_FLOW_FORMAT,
NXT_SET_FLOW_FORMAT, "NXT_SET_FLOW_FORMAT",
- sizeof(struct nxt_set_flow_format), 0 },
+ sizeof(struct nx_set_flow_format), 0 },
{ OFPUTIL_NXT_SET_PACKET_IN_FORMAT,
NXT_SET_PACKET_IN_FORMAT, "NXT_SET_PACKET_IN_FORMAT",
- sizeof(struct nxt_set_packet_in_format), 0 },
+ sizeof(struct nx_set_packet_in_format), 0 },
{ OFPUTIL_NXT_PACKET_IN,
NXT_PACKET_IN, "NXT_PACKET_IN",
- sizeof(struct nxt_packet_in), 1 },
+ sizeof(struct nx_packet_in), 1 },
{ OFPUTIL_NXT_FLOW_MOD,
NXT_FLOW_MOD, "NXT_FLOW_MOD",
@@ -381,7 +381,7 @@ ofputil_decode_vendor(const struct ofp_header *oh, size_t length,
{ OFPUTIL_NXT_FLOW_MOD_TABLE_ID,
NXT_FLOW_MOD_TABLE_ID, "NXT_FLOW_MOD_TABLE_ID",
- sizeof(struct nxt_flow_mod_table_id), 0 },
+ sizeof(struct nx_flow_mod_table_id), 0 },
};
static const struct ofputil_msg_category nxt_category = {
@@ -959,7 +959,7 @@ ofputil_min_flow_format(const struct cls_rule *rule)
struct ofpbuf *
ofputil_make_set_flow_format(enum nx_flow_format flow_format)
{
- struct nxt_set_flow_format *sff;
+ struct nx_set_flow_format *sff;
struct ofpbuf *msg;
sff = make_nxmsg(sizeof *sff, NXT_SET_FLOW_FORMAT, &msg);
@@ -971,7 +971,7 @@ ofputil_make_set_flow_format(enum nx_flow_format flow_format)
struct ofpbuf *
ofputil_make_set_packet_in_format(enum nx_packet_in_format packet_in_format)
{
- struct nxt_set_packet_in_format *spif;
+ struct nx_set_packet_in_format *spif;
struct ofpbuf *msg;
spif = make_nxmsg(sizeof *spif, NXT_SET_PACKET_IN_FORMAT, &msg);
@@ -985,7 +985,7 @@ ofputil_make_set_packet_in_format(enum nx_packet_in_format packet_in_format)
struct ofpbuf *
ofputil_make_flow_mod_table_id(bool flow_mod_table_id)
{
- struct nxt_flow_mod_table_id *nfmti;
+ struct nx_flow_mod_table_id *nfmti;
struct ofpbuf *msg;
nfmti = make_nxmsg(sizeof *nfmti, NXT_FLOW_MOD_TABLE_ID, &msg);
@@ -1618,7 +1618,7 @@ ofputil_decode_packet_in(struct ofputil_packet_in *pin,
pin->buffer_id = ntohl(opi->buffer_id);
pin->total_len = ntohs(opi->total_len);
} else if (code == OFPUTIL_NXT_PACKET_IN) {
- const struct nxt_packet_in *npi;
+ const struct nx_packet_in *npi;
struct cls_rule rule;
struct ofpbuf b;
int error;
@@ -1685,7 +1685,7 @@ ofputil_encode_packet_in(const struct ofputil_packet_in *pin,
ofpbuf_put(packet, pin->packet, send_len);
} else if (packet_in_format == NXPIF_NXM) {
- struct nxt_packet_in *npi;
+ struct nx_packet_in *npi;
struct cls_rule rule;
size_t match_len;
size_t i;
diff --git a/ofproto/ofproto.c b/ofproto/ofproto.c
index 8f3c1586..07d4934b 100644
--- a/ofproto/ofproto.c
+++ b/ofproto/ofproto.c
@@ -2833,8 +2833,8 @@ static int
handle_nxt_flow_mod_table_id(struct ofconn *ofconn,
const struct ofp_header *oh)
{
- const struct nxt_flow_mod_table_id *msg
- = (const struct nxt_flow_mod_table_id *) oh;
+ const struct nx_flow_mod_table_id *msg
+ = (const struct nx_flow_mod_table_id *) oh;
ofconn_set_flow_mod_table_id(ofconn, msg->set != 0);
return 0;
@@ -2843,8 +2843,8 @@ handle_nxt_flow_mod_table_id(struct ofconn *ofconn,
static int
handle_nxt_set_flow_format(struct ofconn *ofconn, const struct ofp_header *oh)
{
- const struct nxt_set_flow_format *msg
- = (const struct nxt_set_flow_format *) oh;
+ const struct nx_set_flow_format *msg
+ = (const struct nx_set_flow_format *) oh;
uint32_t format;
format = ntohl(msg->format);
@@ -2866,10 +2866,10 @@ static int
handle_nxt_set_packet_in_format(struct ofconn *ofconn,
const struct ofp_header *oh)
{
- const struct nxt_set_packet_in_format *msg;
+ const struct nx_set_packet_in_format *msg;
uint32_t format;
- msg = (const struct nxt_set_packet_in_format *) oh;
+ msg = (const struct nx_set_packet_in_format *) oh;
format = ntohl(msg->format);
if (format != NXFF_OPENFLOW10 && format != NXPIF_NXM) {
return ofp_mkerr(OFPET_BAD_REQUEST, OFPBRC_EPERM);
diff --git a/include/openflow/nicira-ext.h b/include/openflow/nicira-ext.h
index bb0fb3a7..f00f9940 100644
--- a/include/openflow/nicira-ext.h
+++ b/include/openflow/nicira-ext.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2008, 2009, 2010, 2011 Nicira Networks
+ * Copyright (c) 2008, 2009, 2010, 2011, 2012 Nicira Networks
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -161,7 +161,7 @@ enum nicira_type {
/* Use the upper 8 bits of the 'command' member in struct ofp_flow_mod to
* designate the table to which a flow is to be added? See the big comment
* on struct nxt_flow_mod_table_id for more information. */
NXT_FLOW_MOD_TABLE_ID = 15,
/* Alternative PACKET_IN message formats. */
@@ -241,14 +241,14 @@ enum nx_hash_fields {
* matches, then it is modified or deleted; if flows in more than one
* table match, then none is modified or deleted.
*/
-struct nxt_flow_mod_table_id {
+struct nx_flow_mod_table_id {
struct ofp_header header;
uint32_t vendor; /* NX_VENDOR_ID. */
uint32_t subtype; /* NXT_FLOW_MOD_TABLE_ID. */
uint8_t set; /* Nonzero to enable, zero to disable. */
uint8_t pad[7];
};
-OFP_ASSERT(sizeof(struct nxt_flow_mod_table_id) == 24);
+OFP_ASSERT(sizeof(struct nx_flow_mod_table_id) == 24);
enum nx_packet_in_format {
NXPIF_OPENFLOW10 = 0, /* Standard OpenFlow 1.0 compatible. */
@@ -256,11 +256,11 @@ enum nx_packet_in_format {
};
/* NXT_SET_PACKET_IN_FORMAT request. */
-struct nxt_set_packet_in_format {
+struct nx_set_packet_in_format {
struct nicira_header nxh;
ovs_be32 format; /* One of NXPIF_*. */
};
-OFP_ASSERT(sizeof(struct nxt_set_packet_in_format) == 20);
+OFP_ASSERT(sizeof(struct nx_set_packet_in_format) == 20);
/* NXT_PACKET_IN (analogous to OFPT_PACKET_IN).
*
@@ -286,7 +286,7 @@ OFP_ASSERT(sizeof(struct nxt_set_packet_in_format) == 20);
*
* The 'cookie' and 'table_id' fields have no meaning when 'reason' is
* OFPR_NO_MATCH. In this case they should be set to 0. */
-struct nxt_packet_in {
+struct nx_packet_in {
struct nicira_header nxh;
ovs_be32 buffer_id; /* ID assigned by datapath. */
ovs_be16 total_len; /* Full length of frame. */
@@ -309,7 +309,7 @@ struct nxt_packet_in {
/* uint8_t pad[2]; */ /* Align to 64 bit + 16 bit. */
/* uint8_t data[0]; */ /* Ethernet frame. */
};
-OFP_ASSERT(sizeof(struct nxt_packet_in) == 40);
+OFP_ASSERT(sizeof(struct nx_packet_in) == 40);
/* Configures the "role" of the sending controller. The default role is:
*
@@ -1732,13 +1732,13 @@ enum nx_flow_format {
};
/* NXT_SET_FLOW_FORMAT request. */
-struct nxt_set_flow_format {
+struct nx_set_flow_format {
struct ofp_header header;
ovs_be32 vendor; /* NX_VENDOR_ID. */
ovs_be32 subtype; /* NXT_SET_FLOW_FORMAT. */
ovs_be32 format; /* One of NXFF_*. */
};
-OFP_ASSERT(sizeof(struct nxt_set_flow_format) == 20);
+OFP_ASSERT(sizeof(struct nx_set_flow_format) == 20);
/* NXT_FLOW_MOD (analogous to OFPT_FLOW_MOD).
*
@@ -161,7 +161,7 @@ enum nicira_type {
/* Use the upper 8 bits of the 'command' member in struct ofp_flow_mod to
* designate the table to which a flow is to be added? See the big comment
- * on struct nxt_flow_mod_table_id for more information. */
+ * on struct nx_flow_mod_table_id for more information. */
NXT_FLOW_MOD_TABLE_ID = 15,
/* Alternative PACKET_IN message formats. */